import 'package:flutter/material.dart';
import 'package:og1_dashboard/src/common/models/app_icon.dart';
import 'package:og1_dashboard/src/common/models/page_layout.dart';
import 'package:og1_dashboard/src/widgets/page_grid.dart';

abstract class IPageService {
  List<Widget> generateGridViews(List<AppIcon> appIcons, Size size);
}

class PageService implements IPageService {
  static final PageService _pageService = PageService._internal();

  factory PageService() {
    return _pageService;
  }

  PageService._internal();

  @override
  List<PageGrid> generateGridViews(List<AppIcon> appIcons, Size size) {
    PageLayout pageLayout = PageLayout(size);
    int appsPerGridView = pageLayout.appsPerPage;
    int i = 0;
    List<PageGrid> gridViews = [];
    appIcons = List.from(Set.from(appIcons));

    while (appIcons.isNotEmpty) {
      if (appIcons.length < appsPerGridView) {
        appsPerGridView = appIcons.length;
      }
      List<AppIcon> gridApps = appIcons.sublist(i, i + appsPerGridView);
      appIcons = List.from(Set.from(appIcons).difference(Set.from(gridApps)));
      gridViews.add(_generateGridView(gridApps, pageLayout));
    }
    return gridViews;
  }

  PageGrid _generateGridView(List<AppIcon> appIcons, PageLayout pageLayout) {
    return PageGrid(appIcons: appIcons, pageLayout: pageLayout);
  }
}
