import 'package:flutter/material.dart';
import 'package:og1_dashboard/src/common/models/app_icon.dart';
import 'package:og1_dashboard/src/common/models/page_layout.dart';
import 'package:og1_system/og1_system.dart';
import 'package:url_launcher/url_launcher.dart';

class PageCell extends StatelessWidget {
  final AppIcon appIcon;
  final PageLayout pageLayout;

  const PageCell({Key? key, required this.appIcon, required this.pageLayout})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: pageLayout.iconWidth + 10,
      child: Column(mainAxisAlignment: MainAxisAlignment.center, children: [
        GestureDetector(
          onTap: appIcon.onTap ?? () => _launchInApp(appIcon.url),
          child: ClipRRect(
            borderRadius: BorderRadius.circular(8.0),
            child: ImageFade(
              image: _image(appIcon.icon),
              duration: const Duration(milliseconds: 900),
              syncDuration: const Duration(milliseconds: 150),
              width: pageLayout.iconWidth,
              height: pageLayout.iconHeight,
              fit: BoxFit.scaleDown,
              alignment: FractionalOffset.center,
              repeat: ImageRepeat.noRepeat,
              errorBuilder: (context, error) => Container(
                alignment: FractionalOffset.center,
                child: const Icon(Icons.broken_image_outlined),
              ),
            ),
          ),
        ),
        Padding(
            padding: const EdgeInsets.only(top: 5),
            child: Text(
              appIcon.title,
              maxLines: 1,
              style: const TextStyle(fontSize: 12),
              overflow: TextOverflow.ellipsis,
            )),
      ]),
    );
  }

  T _image<T extends ImageProvider<Object>>(String icon) {
    return icon.contains('http')
        ? NetworkImage(icon) as T
        : AssetImage(icon) as T;
  }

  Future<void> _launchInApp(String url) async {
    if (await canLaunch(url)) {
      await launch(
        url,
        forceSafariVC: true,
        forceWebView: true,
        enableJavaScript: true,
        enableDomStorage: true,
        headers: <String, String>{'my_header_key': 'my_header_value'},
      );
    } else {
      throw 'Could not launch $url';
    }
  }
}
