import 'package:flutter/material.dart';
import 'package:og1_dashboard/og1_dashboard.dart';
import 'package:og1_dashboard/src/common/models/page_layout.dart';
import 'package:og1_dashboard/src/widgets/grid_cell.dart';

class PageGrid extends StatelessWidget {
  final List<AppIcon> appIcons;
  final PageLayout pageLayout;

  const PageGrid({Key? key, required this.appIcons, required this.pageLayout})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SafeArea(
        child: Column(
            mainAxisAlignment: MainAxisAlignment.spaceAround,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: _generateTableRows(appIcons, pageLayout)));
  }

  List<Row> _generateTableRows(List<AppIcon> appIcons, PageLayout pageLayout) {
    List<Row> tableRows = [];
    List<Widget> tableRowCells = [];

    for (int i = 0; i < pageLayout.appsPerPage; i++) {
      if (i % pageLayout.crossAxisCount == 0) {
        tableRowCells = [];
      }

      i < appIcons.length
          ? tableRowCells.add(PageCell(
              key: UniqueKey(),
              appIcon: appIcons[i],
              pageLayout: pageLayout,
            ))
          : tableRowCells.add(_generateEmptyTableCell());

      if (i % pageLayout.crossAxisCount == 0) {
        Row tableRow = Row(
            mainAxisAlignment: MainAxisAlignment.spaceAround,
            children: tableRowCells);
        tableRows.add(tableRow);
      }
    }
    return tableRows;
  }

  SizedBox _generateEmptyTableCell() => SizedBox(
        width: pageLayout.iconWidth + 10,
        height: pageLayout.iconHeight + 10,
      );
}
